@@ -438,7 +438,7 @@ gpk_modal_dialog_set_remaining (GpkModalDialog *dialog, guint remaining)
 
 	/* get time text */
 	timestring = gpk_time_to_imprecise_string (remaining);
-	text = g_strdup_printf (_("Remaining time : %s"), timestring);
+	text = g_strdup_printf (_("Remaining time: %s"), timestring);
 	gtk_progress_bar_set_text (progress_bar, text);
 out:
 	g_free (timestring);
@@ -908,139 +908,3 @@ gpk_modal_dialog_new (void)
 	dialog = g_object_new (GPK_TYPE_CLIENT_DIALOG, NULL);
 	return GPK_MODAL_DIALOG (dialog);
 }
-
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gpk_modal_dialog_test (EggTest *test)
-{
-	GtkResponseType button;
-	GpkModalDialog *dialog = NULL;
-	GPtrArray *array;
-	PkPackage *item;
-	gboolean ret;
-
-	if (!egg_test_start (test, "GpkModalDialog"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get GpkModalDialog object");
-	dialog = gpk_modal_dialog_new ();
-	if (dialog != NULL)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, NULL);
-
-	/* set some packages */
-	array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-	item = pk_package_new ();
-	ret = pk_package_set_id (item, "totem;001;i386;fedora", NULL);
-	g_assert (ret);
-	g_object_set (item,
-		      "info", PK_INFO_ENUM_INSTALLED,
-		      "summary", "Totem is a music player for GNOME",
-		      NULL);
-	g_ptr_array_add (array, item);
-	item = pk_package_new ();
-	ret = pk_package_set_id (item, "totem;001;i386;fedora", NULL);
-	g_assert (ret);
-	g_object_set (item,
-		      "info", PK_INFO_ENUM_AVAILABLE,
-		      "summary", "Amarok is a music player for KDE",
-		      NULL);
-	g_ptr_array_add (array, item);
-	gpk_modal_dialog_set_package_list (dialog, array);
-	g_ptr_array_unref (array);
-
-	/************************************************************/
-	egg_test_title (test, "help button");
-	gpk_modal_dialog_setup (dialog, GPK_MODAL_DIALOG_PAGE_WARNING, 0);
-	gpk_modal_dialog_set_window_title (dialog, "PackageKit self test");
-	gpk_modal_dialog_set_title (dialog, "Button press test");
-	gpk_modal_dialog_set_message (dialog, "Please press close");
-	gpk_modal_dialog_set_image (dialog, "dialog-warning");
-	gpk_modal_dialog_present (dialog);
-	button = gpk_modal_dialog_run (dialog);
-	if (button == GTK_RESPONSE_CLOSE)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "got id %i", button);
-
-	/************************************************************/
-	egg_test_title (test, "confirm button");
-	gpk_modal_dialog_setup (dialog, GPK_MODAL_DIALOG_PAGE_CONFIRM, 0);
-	gpk_modal_dialog_set_title (dialog, "Button press test with a really really long title");
-	gpk_modal_dialog_set_message (dialog, "Please press Uninstall\n\nThis is a really really, really,\nreally long title <i>with formatting</i>");
-	gpk_modal_dialog_set_image (dialog, "dialog-information");
-	gpk_modal_dialog_set_action (dialog, "Uninstall");
-	gpk_modal_dialog_present (dialog);
-	button = gpk_modal_dialog_run (dialog);
-	if (button == GTK_RESPONSE_OK)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "got id %i", button);
-
-	/************************************************************/
-	egg_test_title (test, "no message");
-	gpk_modal_dialog_setup (dialog, GPK_MODAL_DIALOG_PAGE_PROGRESS, 0);
-	gpk_modal_dialog_set_title (dialog, "Refresh cache");
-	gpk_modal_dialog_set_image_status (dialog, PK_STATUS_ENUM_REFRESH_CACHE);
-	gpk_modal_dialog_set_percentage (dialog, -1);
-	gpk_modal_dialog_present (dialog);
-	gpk_modal_dialog_run (dialog);
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "progress");
-	gpk_modal_dialog_setup (dialog, GPK_MODAL_DIALOG_PAGE_PROGRESS, GPK_MODAL_DIALOG_PACKAGE_PADDING);
-	gpk_modal_dialog_set_title (dialog, "Button press test");
-	gpk_modal_dialog_set_message (dialog, "Please press cancel");
-	gpk_modal_dialog_set_image_status (dialog, PK_STATUS_ENUM_RUNNING);
-	gpk_modal_dialog_set_percentage (dialog, 50);
-	gpk_modal_dialog_present (dialog);
-	button = gpk_modal_dialog_run (dialog);
-	if (button == GTK_RESPONSE_CANCEL)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "got id %i", button);
-
-	/************************************************************/
-	egg_test_title (test, "progress");
-	gpk_modal_dialog_setup (dialog, GPK_MODAL_DIALOG_PAGE_PROGRESS, pk_bitfield_from_enums (GPK_MODAL_DIALOG_WIDGET_MESSAGE, -1));
-	gpk_modal_dialog_set_title (dialog, "Button press test");
-	gpk_modal_dialog_set_message (dialog, "Please press close");
-	gpk_modal_dialog_set_image_status (dialog, PK_STATUS_ENUM_INSTALL);
-	gpk_modal_dialog_set_percentage (dialog, -1);
-	gpk_modal_dialog_present (dialog);
-	button = gpk_modal_dialog_run (dialog);
-	if (button == GTK_RESPONSE_CLOSE)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "got id %i", button);
-
-	/************************************************************/
-	egg_test_title (test, "confirm install button");
-	gpk_modal_dialog_setup (dialog, GPK_MODAL_DIALOG_PAGE_CONFIRM, GPK_MODAL_DIALOG_PACKAGE_LIST);
-	gpk_modal_dialog_set_title (dialog, "Button press test");
-	gpk_modal_dialog_set_message (dialog, "Please press Install if you can see the package list");
-	gpk_modal_dialog_set_image (dialog, "dialog-information");
-	gpk_modal_dialog_set_action (dialog, "Install");
-	gpk_modal_dialog_present (dialog);
-	button = gpk_modal_dialog_run (dialog);
-	if (button == GTK_RESPONSE_OK)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "got id %i", button);
-
-	gpk_modal_dialog_close (dialog);
-
-	g_object_unref (dialog);
-
-	egg_test_end (test);
-}
-#endif
-
